import { Accordion, AccordionItem, AccordionButton, AccordionPanel, Box, Text, VStack, Flex, Spacer } from "@chakra-ui/react";
import { ChevronDownIcon } from "@chakra-ui/icons";
import Link from "next/link";

interface NavigationItem {
  label: string;
  href: string;
}

interface NavigationCategory {
  title: string;
  items: NavigationItem[];
}

interface MobileNavigationProps {
  links: NavigationCategory[];
}

const MobileNavigation: React.FC<MobileNavigationProps> = ({ links }) => {
  return (
    <VStack as="ul" direction={{ base: "column", md: "row" }} justifyContent={{ base: "flex-start", md: "space-between" }} mt={4} spacing={4}>
      <Accordion
        allowToggle={false}
        sx={{
          width: { base: "100%", md: "auto" }, // Adjust as needed
          // Other styles...
        }}>
        {links.map((category, index) => (
          <AccordionItem key={index}>
            <AccordionButton borderWidth={0}>
              <Flex justifyContent={"between"}>
                <Box textAlign="left" color="primary.500" borderWidth={0}>
                  {category.title}
                </Box>
                <Spacer></Spacer>
                <ChevronDownIcon color="primary.500" />
              </Flex>
            </AccordionButton>
            <AccordionPanel>
              <VStack as="ul" align="start" spacing={2} borderWidth={0}>
                {category.items.map((item, i) => (
                  <Link key={i} href={item.href}>
                    <Text fontSize="sm" color="primary.300">
                      {item.label}
                    </Text>
                  </Link>
                ))}
              </VStack>
            </AccordionPanel>
          </AccordionItem>
        ))}
      </Accordion>
    </VStack>
  );
};

export default MobileNavigation;
